pub enum Error {
FileHashDigestChanged {
path: PathBuf,
current_digest: Sha256Checksum,
initial_digest: Sha256Checksum,
input_dir: PathBuf,
},
FileIsMissing {
path: PathBuf,
input_dir: PathBuf,
},
MetadataMismatch {
mismatches: Vec<MetadataMismatch>,
},
}Expand description
An error that can occur when dealing with package input directories and package files.
Variants
FileHashDigestChanged
The hash digest of a file in an input directory no longer matches.
Fields

current_digest: Sha256ChecksumThe current hash digest of the file.

initial_digest: Sha256ChecksumThe initial hash digest of the file.
FileIsMissing
A file is missing in a package input directory.
Fields
MetadataMismatch
Two metadata files have mismatching entries.
Fields

mismatches: Vec<MetadataMismatch>A list of mismatches.